Lists the columns of each base table referenced by the query so sqlglot
can resolve unqualified columns and expand *. Returns NULL if the
schema cannot be determined (lineage extraction still works, with
reduced attribution accuracy).
Lists the columns of each base table referenced by the query so sqlglot
can resolve unqualified columns and expand *. Returns NULL if the
schema cannot be determined (lineage extraction still works, with
reduced attribution accuracy).